from rq import Worker
from rq.utils import import_attribute

from .queues import get_queues
from .settings import EXCEPTION_HANDLERS


def get_exception_handlers():
    """
    Custom exception handlers could be defined in settings.py:
    RQ = {
        'EXCEPTION_HANDLERS': ['path.to.handler'],
    }
    """
    return [import_attribute(path) for path in EXCEPTION_HANDLERS]


def get_worker(*queue_names):
    """
    Returns a RQ worker for all queues or specified ones.
    """
    queues = get_queues(*queue_names)
    return Worker(queues,
                  connection=queues[0].connection,
                  exception_handlers=get_exception_handlers() or None)



from django.conf.urls import include, url
from django.contrib import admin

from django_rq.tests import views

urlpatterns = [
    url(r'^django-rq/', include('django_rq.urls')),
    url(r'^admin/', include(admin.site.urls)),
    url(r'^success/$', views.success, name='success'),
    url(r'^error/$', views.error, name='error'),
]



from distutils.version import LooseVersion
from django import template
from django.utils.version import get_version


register = template.Library()

if LooseVersion(get_version()) >= LooseVersion('1.9'):
    JQUERY_PATH = 'admin/js/vendor/jquery/jquery.js'

    # `assignment_tag` is deprecated as of 1.9, `simple_tag` should be used
    tag_decorator = register.simple_tag
else:
    JQUERY_PATH = 'admin/js/jquery.js'
    tag_decorator = register.assignment_tag


@register.assignment_tag
def get_jquery_path():
    return JQUERY_PATH
